"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.SyntaxHighlighter = void 0;
var _core = require("@shikijs/core");
var _engineJavascript = require("@shikijs/engine-javascript");
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _style = require("../utils/style");
var _jsxRuntime = require("react/jsx-runtime");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
// Static highlighter instance
let highlighterInstance = null;

// Registry to store loaded languages
const registeredLanguages = {};

// Initialize highlighter if needed
async function getHighlighter() {
  if (!highlighterInstance) {
    highlighterInstance = await (0, _core.createHighlighterCore)({
      engine: (0, _engineJavascript.createJavaScriptRegexEngine)()
    });
  }
  return highlighterInstance;
}
const SyntaxHighlighter = ({
  text,
  language,
  theme,
  fontSize = 14,
  textStyle,
  scrollViewProps,
  containerStyle
}) => {
  const [tokens, setTokens] = _react.default.useState([]);
  const [loading, setLoading] = _react.default.useState(true);
  const [error, setError] = _react.default.useState(null);
  const stylesheet = (0, _react.useMemo)(() => (0, _style.getStylesFromShikiTheme)(theme), [theme]);
  _react.default.useEffect(() => {
    const highlight = async () => {
      try {
        setLoading(true);
        const highlighter = await getHighlighter();

        // Check if language is registered
        const normalizedLang = language.toLowerCase();
        if (!registeredLanguages[normalizedLang]) {
          throw new Error(`Language '${normalizedLang}' not registered. Use SyntaxHighlighter.registerLanguage() to add it.`);
        }

        // Load theme
        await highlighter.loadTheme(theme);
        const themeName = theme.name || Object.getOwnPropertyDescriptor(theme, 'name')?.value || 'default';

        // Highlight the code
        const result = highlighter.codeToTokens(text, {
          lang: normalizedLang,
          theme: themeName
        });
        setTokens(result.tokens);
        setError(null);
      } catch (err) {
        setError(err instanceof Error ? err.message : 'Failed to highlight code');
        console.error('Highlighting error:', err);
      } finally {
        setLoading(false);
      }
    };
    highlight();
  }, [text, language, theme]);
  const renderToken = (token, index) => {
    const scopeStyles = token.explanation?.[0]?.scopes.map(scope => stylesheet[scope.scopeName]).filter(Boolean) || [];
    const style = _reactNative.StyleSheet.flatten([textStyle, {
      fontSize
    }, ...scopeStyles, token.color ? {
      color: token.color
    } : null, token.fontStyle === 1 && {
      fontStyle: 'italic'
    }, token.fontStyle === 2 && {
      fontWeight: 'bold'
    }, token.fontStyle === 4 && {
      textDecorationLine: 'underline'
    }]);
    return /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.Text, {
      style: style,
      children: token.content
    }, `${token.offset}-${index}`);
  };
  const renderLine = (lineTokens, index) => /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.View, {
    style: {
      flexDirection: 'row',
      flexWrap: 'wrap'
    },
    children: lineTokens.map((token, tokenIndex) => renderToken(token, tokenIndex))
  }, index);
  if (loading) {
    return /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.View, {
      style: [stylesheet.root, {
        padding: 10
      }, containerStyle],
      children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.ActivityIndicator, {})
    });
  }
  if (error) {
    return /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.View, {
      style: [stylesheet.root, {
        padding: 10
      }, containerStyle],
      children: /*#__PURE__*/(0, _jsxRuntime.jsxs)(_reactNative.Text, {
        style: {
          color: '#ff6b6b'
        },
        children: ["Error:", error]
      })
    });
  }
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.ScrollView, {
    ...scrollViewProps,
    horizontal: true,
    style: [stylesheet.root, scrollViewProps?.style],
    contentContainerStyle: [containerStyle],
    children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.View, {
      onStartShouldSetResponder: () => true,
      children: tokens.map((lineTokens, index) => renderLine(lineTokens, index))
    })
  });
};

// Static method to register languages
exports.SyntaxHighlighter = SyntaxHighlighter;
SyntaxHighlighter.registerLanguage = async (name, language) => {
  const normalizedName = name.toLowerCase();
  registeredLanguages[normalizedName] = language;

  // If highlighter exists, load the language immediately
  if (highlighterInstance) {
    await highlighterInstance.loadLanguage(language);
  }
};
//# sourceMappingURL=SyntaxHighlighter.js.map